import os
import logging
import uuid
from flask import Flask, render_template, request, jsonify, g, session, url_for
from flask_babel import Babel
from werkzeug.utils import secure_filename

# Configure logging
logging.basicConfig(level=logging.DEBUG)

# Create Flask app
app = Flask(__name__)
app.secret_key = os.environ.get("SESSION_SECRET", "dev-secret-key")

# Configure upload folder for car images
UPLOAD_FOLDER = os.path.join(app.static_folder, 'uploads')
if not os.path.exists(UPLOAD_FOLDER):
    os.makedirs(UPLOAD_FOLDER)
app.config['UPLOAD_FOLDER'] = UPLOAD_FOLDER
app.config['MAX_CONTENT_LENGTH'] = 16 * 1024 * 1024  # 16MB max upload size
ALLOWED_EXTENSIONS = {'png', 'jpg', 'jpeg', 'gif'}

# Supported languages
LANGUAGES = {
    'en': 'English',
    'de': 'Deutsch'
}

# Get user locale - this will be used by Babel
def get_locale():
    # First check if the language is set in the session
    if 'language' in session:
        app.logger.debug(f"Language from session: {session['language']}")
        return session['language']
    
    # Otherwise try to guess the language from the user accept header
    best_match = request.accept_languages.best_match(LANGUAGES.keys())
    app.logger.debug(f"Best match language: {best_match}")
    if best_match is None:
        return 'de'  # Default to German if no match
    return best_match

# Configure Babel for internationalization
babel = Babel(app, locale_selector=get_locale)

@app.before_request
def before_request():
    # Set the language code in g for templates to use
    if 'language' in session:
        g.lang_code = session.get('language', 'de')
    else:
        g.lang_code = request.accept_languages.best_match(LANGUAGES.keys()) or 'de'
    app.logger.debug(f"Current language: {g.lang_code}")

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/set-language/<language>')
def set_language(language):
    session['language'] = language
    return jsonify({'status': 'success'})

def allowed_file(filename):
    return '.' in filename and \
           filename.rsplit('.', 1)[1].lower() in ALLOWED_EXTENSIONS

@app.route('/upload-image', methods=['POST'])
def upload_image():
    if 'file' not in request.files:
        return jsonify({'error': 'No file part'}), 400
    
    file = request.files['file']
    if file.filename == '':
        return jsonify({'error': 'No selected file'}), 400
    
    if file and allowed_file(file.filename):
        # Create unique filename
        filename = secure_filename(file.filename)
        unique_filename = f"{uuid.uuid4().hex}_{filename}"
        
        # Save the file
        file_path = os.path.join(app.config['UPLOAD_FOLDER'], unique_filename)
        file.save(file_path)
        
        # Return the file path relative to static folder for use in frontend
        return jsonify({
            'status': 'success',
            'file_path': f'/uploads/{unique_filename}'
        })
    
    return jsonify({'error': 'File type not allowed'}), 400

@app.route('/submit-car', methods=['POST'])
def submit_car():
    # In a real application, this would save the form data to a database
    if request.method == 'POST':
        # Get JSON data from request
        data = request.get_json()
        
        # Log form data for debugging
        app.logger.debug(f"Car form data: {data}")
        
        # Here you would process and store the data
        # For now, we'll just return a success message
        return jsonify({'status': 'success', 'message': 'Your car listing has been submitted'})

@app.route('/submit-contact', methods=['POST'])
def submit_contact():
    # In a real application, this would send an email or save to a database
    if request.method == 'POST':
        # Get JSON data from request
        data = request.get_json()
        
        # Log form data for debugging
        app.logger.debug(f"Contact form data: {data}")
        
        # Here you would process the contact form data
        # For now, we'll just return a success message
        return jsonify({'status': 'success', 'message': 'Your message has been sent'})

if __name__ == '__main__':
    app.run(host='0.0.0.0', port=5000, debug=True)
